/* This is the EPICS dependent code for the XIA xMAP driver module.
 * By making this separate file for the EPICS dependent code the driver itself
 * only needs libCom from EPICS for OS-independence (i.e. it is then possible to create
 * module tests withouth needing to load the entire EPICS libraries!)
 */

#include <iocsh.h>
#include <drvSup.h>
#include <epicsExport.h>

#include "adXmap.h"

static const iocshArg ADXmapConfigArg0 = {"Asyn port name", iocshArgString};
static const iocshArg ADXmapConfigArg1 = {"Number of cards", iocshArgInt};
static const iocshArg ADXmapConfigArg2 = {"XIA Handel init file", iocshArgString};
static const iocshArg ADXmapConfigArg3 = {"Maximum number of buffers", iocshArgInt};
static const iocshArg ADXmapConfigArg4 = {"Maximum amount of memory (bytes)", iocshArgInt};
static const iocshArg * const ADXmapConfigArgs[] =  {&ADXmapConfigArg0,
                                                     &ADXmapConfigArg1,
                                                     &ADXmapConfigArg2,
                                                     &ADXmapConfigArg3,
                                                     &ADXmapConfigArg4};
static const iocshFuncDef configADXmap = {"xmapConfig", 5, ADXmapConfigArgs};
static void configADXmapCallFunc(const iocshArgBuf *args)
{
	/*ADXmap_config(const char *portName, int nCards, const char *iniFile, int maxBuffers, size_t maxMemory);*/
	ADXmap_config(args[0].sval, args[1].ival, args[2].sval, args[3].ival, args[4].ival);
}

static const iocshArg ADXmapMapFileConfigArg0 = {"Asyn port name", iocshArgString};
static const iocshArg ADXmapMapFileConfigArg1 = {"Max queue size", iocshArgInt};
static const iocshArg ADXmapMapFileConfigArg2 = {"NDArray asyn port", iocshArgString};
static const iocshArg ADXmapMapFileConfigArg3 = {"NDArray asyn address", iocshArgInt};
static const iocshArg ADXmapMapFileConfigArg4 = {"Maximum number of buffers", iocshArgInt};
static const iocshArg ADXmapMapFileConfigArg5 = {"Maximum amount of memory (bytes)", iocshArgInt};
static const iocshArg * const ADXmapMapFileConfigArgs[] =  {&ADXmapMapFileConfigArg0,
                                                     &ADXmapMapFileConfigArg1,
                                                     &ADXmapMapFileConfigArg2,
                                                     &ADXmapMapFileConfigArg3,
                                                     &ADXmapMapFileConfigArg4,
                                                     &ADXmapMapFileConfigArg5};
static const iocshFuncDef configADXmapMapFile = {"xmapMapFileConfig", 6, ADXmapMapFileConfigArgs};
static void configADXmapMapFileCallFunc(const iocshArgBuf *args)
{
	ADXmap_MapFileConfig(args[0].sval, args[1].ival, args[2].sval, args[3].ival, args[4].ival, args[5].ival);
}


static void ADXmapRegister(void)
{
    iocshRegister(&configADXmap, configADXmapCallFunc);
    iocshRegister(&configADXmapMapFile, configADXmapMapFileCallFunc);
}

epicsExportRegistrar(ADXmapRegister);
